@@ -468,8 +468,6 @@
 
 
 (define (set-cards! slot-id new_cards)
-;  (if IN-GAME 
-;      (record-move slot-id new_cards (get-cards slot-id)))
   (set-cards-c! slot-id new_cards))
 
 ; Since the cards get thrown around between C and scheme a lot we
@@ -478,7 +476,7 @@
 ; (i.e. at the beginning of a new game) then we clean out the old 
 ; cards from the guardian.
 (if (defined? 'card-guardian)
-    (while (card-guardian))
+    (while (card-guardian) #t)
     (define card-guardian (make-guardian)))
 
 (define (make-card value suit)
