@@ -52,6 +52,7 @@
 #define KEY_NMINES "/apps/gnomine/geometry/nmines"
 #define KEY_MODE "/apps/gnomine/geometry/mode"
 #define KEY_USE_QUESTION_MARKS "/apps/gnomine/use_question_marks"
+#define KEY_USE_OVERMINE_WARNING "/apps/gnomine/use_overmine_warning"
 #define KEY_WIDTH    	       "/apps/gnomine/geometry/width"
 #define KEY_HEIGHT   	       "/apps/gnomine/geometry/height"
 
@@ -72,6 +73,7 @@ gint ysize = -1, xsize = -1;
 gint nmines = -1;
 gint fsize = -1;
 gboolean use_question_marks = TRUE;
+gboolean use_overmine_warning = TRUE;
 
 GtkAction *hint_action;
 GtkAction *fullscreen_action;
@@ -273,6 +275,7 @@ new_game (void)
 		y = size_table[fsize][1];
 		mf->mcount = size_table[fsize][2];
 	}
+
 	games_scores_set_category (highscores, scorecats[fsize].key);
 	gtk_minefield_set_size (GTK_MINEFIELD (mfield), x, y);
 	gtk_minefield_restart (GTK_MINEFIELD (mfield));
@@ -416,12 +419,6 @@ about_callback (void)
 		_("Main game:"),
 		"Szekeres Istvan",
 		"",
-		_("Faces:"),
-		"Tuomas Kuosmanen",
-		"",
-		_("Graphics:"),
-		"Richard Hoelscher",
-		"",
 		_("Score:"),
 		"Horacio J. Pe\xc3\xb1""a",
 		"",
@@ -431,13 +428,35 @@ about_callback (void)
 		NULL
 	};
 
+	const gchar *artists[] = {
+		_("Faces:"),
+		"Tuomas Kuosmanen",
+		"",
+		_("Graphics:"),
+		"Richard Hoelscher",
+		NULL
+	};
+
+	const gchar *documenters[] = {
+		"Callum McKenzie",
+		NULL
+	};
+
 	gtk_show_about_dialog (GTK_WINDOW(window),
 			       "name", _("Mines"),
 			       "version", VERSION,
-			       "copyright", "Copyright \xc2\xa9 1997-2004 Free Software Foundation, Inc.",
+			       "comments", _("The popular logic puzzle minesweeper. "
+					     "Clear mines from a board using hints from "
+					     "squares you have already uncovered."),
+			       "copyright", "Copyright \xc2\xa9 1997-2006 Free Software Foundation, Inc.",
+			       "license", "GPL 2+",
 			       "authors", authors,
+			       "artists", artists,
+			       "documenters", documenters,
 			       "translator_credits", _("translator-credits"),
 			       "logo-icon-name", "gnome-gnomine",
+			       "website", "http://www.gnome.org/projects/gnome-games/",
+			       "wrap-license", TRUE,
 			       NULL);
 }
 
@@ -487,6 +506,10 @@ gconf_key_change_cb (GConfClient *client, guint cnxn_id,
 		use_question_marks = value ? gconf_value_get_bool (value) : TRUE;
 		gtk_minefield_set_use_question_marks(GTK_MINEFIELD(mfield), use_question_marks);
 	}
+	if (strcmp (key, KEY_USE_OVERMINE_WARNING) == 0) {
+		use_overmine_warning = value ? gconf_value_get_bool (value) : TRUE;
+		gtk_minefield_set_use_overmine_warning(GTK_MINEFIELD(mfield), use_overmine_warning);
+	}
 }
 
 static void
@@ -556,6 +579,14 @@ use_question_toggle_cb (GtkCheckButton *check, gpointer data)
 				use_marks, NULL);
 }
 
+static void
+use_overmine_toggle_cb (GtkCheckButton *check, gpointer data)
+{
+	gboolean use_overmine = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check));
+	gconf_client_set_bool (conf_client, KEY_USE_OVERMINE_WARNING,
+				use_overmine, NULL);
+}
+
 static void
 set_fullscreen_actions (gboolean is_fullscreen)
 {
@@ -594,10 +625,11 @@ create_preferences (void)
 	GtkWidget *table2;
 	GtkWidget *label2;
 	GtkWidget *question_toggle;        
+	GtkWidget *overmine_toggle;
 	GtkWidget *xentry;
 	GtkWidget *yentry;
 
-	table = gtk_table_new (2, 2, FALSE);
+	table = gtk_table_new (3, 2, FALSE);
 	gtk_container_set_border_width (GTK_CONTAINER (table), 5);
 	gtk_table_set_row_spacings (GTK_TABLE (table), 18);
 	gtk_table_set_col_spacings (GTK_TABLE (table), 18);
@@ -706,6 +738,15 @@ create_preferences (void)
 	gtk_table_attach_defaults (GTK_TABLE (table), question_toggle, 0, 2, 1, 2);
 
 
+	overmine_toggle = gtk_check_button_new_with_mnemonic(_("_Use \"Too many flags\" warning"));
+	g_signal_connect(GTK_OBJECT(overmine_toggle), "toggled",
+			GTK_SIGNAL_FUNC (use_overmine_toggle_cb), NULL);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(overmine_toggle), use_overmine_warning);
+	gtk_widget_show(overmine_toggle);
+	
+	gtk_table_attach_defaults (GTK_TABLE (table), overmine_toggle, 0, 2, 2, 3);
+
+
 	pref_dialog = gtk_dialog_new_with_buttons (_("Mines Preferences"),
 			GTK_WINDOW (window),
 			0,
@@ -844,16 +885,6 @@ save_state (GnomeClient        *client,
 
 static int xpos = -1, ypos = -1;
 
-static struct poptOption options[] = {
-  {NULL, 'x', POPT_ARG_INT, &xsize, 0, N_("Width of grid"), N_("X")},
-  {NULL, 'y', POPT_ARG_INT, &ysize, 0, N_("Height of grid"), N_("Y")},
-  {NULL, 'n', POPT_ARG_INT, &nmines, 0, N_("Number of mines"), N_("NUMBER")},
-  {NULL, 'f', POPT_ARG_INT, &fsize, 0, N_("Size of the board (1=small, 3=large)"), NULL},
-  {NULL, 'a', POPT_ARG_INT, &xpos, 0, N_("X location of window"), N_("X")},
-  {NULL, 'b', POPT_ARG_INT, &ypos, 0, N_("Y location of window"), N_("Y")},
-  {NULL, '\0', 0, NULL, 0}
-};
-
 #if 0
 static void 
 sound_eos (GstElement *sound_player, gpointer data)
@@ -880,6 +911,9 @@ sound_init (int * argcp, char ** argvp[])
 int
 main (int argc, char *argv[])
 {
+       GnomeProgram *program;
+       GOptionContext *context;
+
         GtkWidget *all_boxes;
 	GtkWidget *status_box;
 	GtkWidget *button_table;
@@ -892,17 +926,30 @@ main (int argc, char *argv[])
 
 	gint width, height;
 
+        static const GOptionEntry options[] = {
+                {"width", 'x', 0, G_OPTION_ARG_INT, &xsize,  N_("Width of grid"), N_("X")},
+                {"height", 'y', 0, G_OPTION_ARG_INT, &ysize,  N_("Height of grid"), N_("Y")},
+                {"mines", 'n', 0, G_OPTION_ARG_INT, &nmines, N_("Number of mines"), N_("NUMBER")},
+                {"size", 'f', 0, G_OPTION_ARG_INT, &fsize,  N_("Size of the board (0-2 = small-large, 3=custom)"), NULL},
+                {"a", 'a', 0, G_OPTION_ARG_INT, &xpos,   N_("X location of window"), N_("X")},
+                {"b", 'b', 0, G_OPTION_ARG_INT, &ypos,   N_("Y location of window"), N_("Y")},
+                {NULL}
+        };
+
 	setgid_io_init ();
 
 	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
-	gnome_program_init ("gnomine", VERSION,
-			LIBGNOMEUI_MODULE,
-			argc, argv,
-			GNOME_PARAM_POPT_TABLE, options,
-			GNOME_PARAM_APP_DATADIR, DATADIR, NULL);
+        context = g_option_context_new ("");
+        g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
+	
+        program = gnome_program_init ("gnomine", VERSION, LIBGNOMEUI_MODULE,
+				      argc, argv,
+				      GNOME_PARAM_APP_DATADIR, DATADIR,
+				      GNOME_PARAM_GOPTION_CONTEXT, context,
+				      NULL);
 
 	highscores = games_scores_new (&scoredesc);
 
@@ -941,6 +988,9 @@ main (int argc, char *argv[])
 	use_question_marks = gconf_client_get_bool (conf_client, 
 						    KEY_USE_QUESTION_MARKS,
 						    NULL);
+	use_overmine_warning = gconf_client_get_bool (conf_client, 
+						      KEY_USE_OVERMINE_WARNING,
+						      NULL);
 	width = gconf_client_get_int (conf_client, KEY_WIDTH, NULL);
 	width = width > 0 ? width : WIDTH_DEFAULT;
 	height = gconf_client_get_int (conf_client, KEY_HEIGHT, NULL);
@@ -1026,6 +1076,9 @@ main (int argc, char *argv[])
 	gtk_minefield_set_use_question_marks (GTK_MINEFIELD (mfield),
 					      use_question_marks);
 	
+	gtk_minefield_set_use_overmine_warning (GTK_MINEFIELD (mfield),
+					      use_overmine_warning);
+	
 	g_signal_connect (G_OBJECT (mfield), "marks_changed",
 			  G_CALLBACK (marks_changed), NULL);
 	g_signal_connect (G_OBJECT (mfield), "explode",
@@ -1084,5 +1137,7 @@ main (int argc, char *argv[])
 	
 	gnome_accelerators_sync();
 
+	g_object_unref (program);
+
 	return 0;
 }
